# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-04-29 11:23
# @Author : 毛鹏

from ..enums._enums import StatusEnum, NoticeEnum, CacheValueTypeEnum

__all__ = [
    'StatusEnum',
    'NoticeEnum',
    'CacheValueTypeEnum',
]



from setuptools import setup, find_packages

__version__ = '1.1.28'

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='mangotools',
    version=__version__,
    description='测试工具',
    long_description=long_description,
    package_data={
        'mangotools': [
            'mangos/*',
            'mangos/**/*',
        ]
    },
    include_package_data=True,
    author='毛鹏',
    author_email='729164035@qq.com',
    url='https://gitee.com/mao-peng/testkit',
    packages=find_packages(),
    install_requires=[
        'aiomysql>=0.2.0',
        'PyMySQL>=1.1.1',
        'jsonpath>=0.82.2',
        'cachetools>=5.3.1',
        'Faker>=24.1.0',
        'diskcache>=5.6.3',
        'pydantic>=2.9.2',
        'colorlog>=6.7.0',
        'assertpy>=1.1',
        'deepdiff>=8.0.1',
        'requests>=2.32.3',
        'openpyxl>=3.1.5'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
    ]
)

"""


python -m pip install --upgrade setuptools wheel
python -m pip install --upgrade twine

python setup.py check
python setup.py sdist bdist_wheel
twine upload --repository-url https://upload.pypi.org/legacy/ dist/*

"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-04-30 17:12
# @Author : 毛鹏
import json
import tempfile

from mangotools.data_processor import SqlCache
from mangotools.enums import CacheValueTypeEnum

temp_db = tempfile.NamedTemporaryFile(delete=False)
temp_db.close()
db_path = temp_db.name

cache = SqlCache(db_path)

cache.set_sql_cache("test_str", "hello world", CacheValueTypeEnum.STR)
print(type(cache.get_sql_cache("test_str")), cache.get_sql_cache("test_str"))
assert cache.get_sql_cache("test_str") == "hello world"

cache.set_sql_cache("test_int", 42, CacheValueTypeEnum.INT)
print(type(cache.get_sql_cache("test_int")), cache.get_sql_cache("test_int"))
assert cache.get_sql_cache("test_int") == 42

cache.set_sql_cache("test_float", 3.14, CacheValueTypeEnum.FLOAT)
print(type(cache.get_sql_cache("test_float")), cache.get_sql_cache("test_float"))
assert cache.get_sql_cache("test_float") == 3.14

cache.set_sql_cache("test_bool", True, CacheValueTypeEnum.BOOL)
print(type(cache.get_sql_cache("test_bool")), cache.get_sql_cache("test_bool"))
assert cache.get_sql_cache("test_bool") is True

cache.set_sql_cache("test_none", None, CacheValueTypeEnum.NONE)
print(type(cache.get_sql_cache("test_none")), cache.get_sql_cache("test_none"))
assert cache.get_sql_cache("test_none") is None

test_list = [1, 2, 3, "four"]
cache.set_sql_cache("test_list", test_list, CacheValueTypeEnum.LIST)
print(type(cache.get_sql_cache("test_list")), cache.get_sql_cache("test_list"))
assert cache.get_sql_cache("test_list") == test_list

test_dict = {"a": 1, "b": 2, "c": "three"}
cache.set_sql_cache("test_dict", test_dict, CacheValueTypeEnum.DICT)
print(type(cache.get_sql_cache("test_dict")), cache.get_sql_cache("test_dict"))
assert cache.get_sql_cache("test_dict") == test_dict

test_tuple = (1, 2, 3, "four")
cache.set_sql_cache("test_tuple", test_tuple, CacheValueTypeEnum.TUPLE)
print(type(cache.get_sql_cache("test_tuple")), cache.get_sql_cache("test_tuple"))
assert cache.get_sql_cache("test_tuple") == test_tuple

test_json = {"name": "John", "age": 30, "city": "New York"}
cache.set_sql_cache("test_json", test_json, CacheValueTypeEnum.JSON)
print(type(cache.get_sql_cache("test_json")), cache.get_sql_cache("test_json"))
assert cache.get_sql_cache("test_json") == test_json

print(json.dumps(cache.get_sql_all()))
print("测试包含。..")
assert cache.contains_sql_cache("test_str") is True
assert cache.contains_sql_cache("nonexistent") is False

print("测试删除。..")
cache.delete_sql_cache("test_str")
assert cache.get_sql_cache("test_str") is None
assert cache.contains_sql_cache("test_str") is False

print("测试清除。..")
cache.clear_sql_cache()
assert cache.get_sql_cache("test_int") is None
assert cache.contains_sql_cache("test_int") is False

print("所有测试均已通过！")



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-01-21 11:42
# @Author : 毛鹏
from mangotools.data_processor import DataProcessor


def test_001():
    """设置缓存和使用华城"""
    value = '设置到缓存中'
    processor = DataProcessor()
    processor.set_cache('value', value)  # 首先我们把value设置一个值
    assert processor.get_cache('value') == value
    return processor.get_cache('value')


def test_002():
    """替换${{}}中间的内容"""
    key = '芒果测试平台'
    value = '替换：${{key}}'
    processor = DataProcessor()
    processor.set_cache('key', key)  # 首先我们把value设置一个值
    assert processor.replace(value) == '替换：芒果测试平台'
    return processor.replace(value)  # 调用replace进行替换


def test_003():
    """获取公共方法中的数据"""
    processor = DataProcessor()
    assert processor.replace('${{md5_32_small(123456)}}') is not None
    return processor.replace('${{md5_32_small(123456)}}')


def test_004():
    """直接将获取到的内容存到缓存中"""
    str_ = "我是基于时间戳的5位随机数：${{number_time_5()|flow名称}}"
    processor = DataProcessor()
    value = processor.replace(str_)
    assert value == f"我是基于时间戳的5位随机数：{processor.get_cache('flow名称')}"
    return f"我是基于时间戳的5位随机数：{processor.get_cache('flow名称')}"


if __name__ == '__main__':
    print(f"方法：{test_001.__name__}：{test_001()}")
    print(f"方法：{test_002.__name__}：{test_002()}")
    print(f"方法：{test_003.__name__}：{test_003()}")
    print(f"方法：{test_004.__name__}：{test_004()}")
    from mangotools.mangos.pyarmor_runtime_windows.mango import Mango
    Mango.v(1)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-24 11:02
# @Author : 毛鹏
from .mango import *
from .model_crud import *

__all__ = [
    'Mango',
    'test',
    'get',
    'post',
    'put',
    'delete',
    'inside_post',
    'inside_put',
    'inside_delete',
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-04-12 18:07
# @Author : 毛鹏
from enum import Enum


class BaseEnum(Enum):
    """基础枚举类，提供通用的三个方法"""

    @classmethod
    def get_option(cls, k='key', v='title') -> list:
        return [{k: key, v: value} for key, value in cls.obj().items()]  # type: ignore

    @classmethod
    def get_obj(cls) -> dict:
        return cls.obj()  # type: ignore

    @classmethod
    def get_value_list(cls) -> list:
        return [value for key, value in cls.obj().items()]  # type: ignore

    @classmethod
    def get_key_list(cls) -> list:
        return [key for key, value in cls.obj().items()]  # type: ignore

    @classmethod
    def get_value(cls, key: int):
        return cls.obj().get(key)  # type: ignore

    @classmethod
    def get_key(cls, value):
        all_values = cls.obj().values()  # type: ignore
        if value in all_values:
            keys_with_target_value = [k for k, v in cls.obj().items() if v == value]  # type: ignore
            for key in keys_with_target_value:
                return key
